[gnome-panel] libpanel-applet/panel-applet.h: Rename id to factory_id for factory macros



commit d0a0f5fb6cd4e58b2a3e831ac0bda1b871dcea41
Author: Sebastian Geiger <sbastig gmx net>
Date:   Mon Aug 24 00:27:08 2015 +0200

    libpanel-applet/panel-applet.h: Rename id to factory_id for factory macros

 libpanel-applet/panel-applet.h |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/libpanel-applet/panel-applet.h b/libpanel-applet/panel-applet.h
index 4efee48..dd6066e 100644
--- a/libpanel-applet/panel-applet.h
+++ b/libpanel-applet/panel-applet.h
@@ -200,7 +200,7 @@ int                panel_applet_factory_setup_in_process (const gchar
 
 /**
  * PANEL_APPLET_OUT_PROCESS_FACTORY:
  * @id: identifier of an applet factory.
  * @type: GType of the applet this factory creates.
  * @callback: (scope call): a %PanelAppletFactoryCallback to be called
  *     when a new applet is created.
@@ -221,7 +221,7 @@ int                panel_applet_factory_setup_in_process (const gchar
  * It can only be used once, and is incompatible with the use of
  * %PANEL_APPLET_IN_PROCESS_FACTORY and panel_applet_factory_main().
  **/
-#define PANEL_APPLET_OUT_PROCESS_FACTORY(id, type, callback, data)             \
+#define PANEL_APPLET_OUT_PROCESS_FACTORY(factory_id, type, callback, data)      \
 int main (int argc, char *argv [])                                             \
 {                                                                              \
        GOptionContext *context;                                                \
@@ -247,7 +247,7 @@ int main (int argc, char *argv [])                                          \
                                                                                \
        gtk_init (&argc, &argv);                                                \
                                                                                 \
-        retval = panel_applet_factory_main (id, type, callback, data);          \
+        retval = panel_applet_factory_main (factory_id, type, callback, data);  \
        g_option_context_free (context);                                        \
                                                                                \
        return retval;                                                          \
@@ -255,7 +255,7 @@ int main (int argc, char *argv [])                                          \
 
 /**
  * PANEL_APPLET_IN_PROCESS_FACTORY:
  * @id: identifier of an applet factory.
  * @type: GType of the applet this factory creates.
  * @callback: (scope call): a %PanelAppletFactoryCallback to be called
  *     when a new applet is created.
@@ -275,13 +275,13 @@ int main (int argc, char *argv [])                                                \
  * It can only be used once, and is incompatible with the use of
  * %PANEL_APPLET_OUT_PROCESS_FACTORY and panel_applet_factory_main().
  **/
-#define PANEL_APPLET_IN_PROCESS_FACTORY(id, type, callback, data)              \
+#define PANEL_APPLET_IN_PROCESS_FACTORY(factory_id, type, callback, data)       \
 gboolean _panel_applet_shlib_factory (void);                                   \
 G_MODULE_EXPORT gint                                                            \
 _panel_applet_shlib_factory (void)                                             \
 {                                                                              \
        _PANEL_APPLET_SETUP_GETTEXT (FALSE);                                    \
-        return panel_applet_factory_setup_in_process (id, type,                 \
+        return panel_applet_factory_setup_in_process (factory_id, type,         \
                                                       callback, data);          \
 }
 
@@ -200,7 +200,7 @@ int                panel_applet_factory_setup_in_process (const gchar
 /**
  * PANEL_APPLET_OUT_PROCESS_FACTORY:
- * @id: identifier of an applet factory.
+ * @factory_id: identifier of an applet factory.
  * @type: GType of the applet this factory creates.
  * @callback: (scope call): a %PanelAppletFactoryCallback to be called
@@ -255,7 +255,7 @@ int main (int argc, char *argv [])                                          \
 /**
  * PANEL_APPLET_IN_PROCESS_FACTORY:
- * @id: identifier of an applet factory.
+ * @factory_id: identifier of an applet factory.
  * @type: GType of the applet this factory creates.
  * @callback: (scope call): a %PanelAppletFactoryCallback to be called


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]